@@ -16,11 +16,9 @@
 # along with HyperSpy. If not, see <http://www.gnu.org/licenses/>.
 
 
-import os
-
 import numpy as np
+from nose.tools import assert_true, assert_equal
 
-from nose.tools import assert_true, assert_equal, assert_not_equal
 from hyperspy._signals.spectrum import Spectrum
 from hyperspy.hspy import create_model
 from hyperspy.components import Gaussian
